@@ -6,12 +6,12 @@ from pydantic import UUID4
 
 from fief.crypto.access_token import generate_access_token
 from fief.crypto.id_token import generate_id_token
-from fief.dependencies.account_managers import get_refresh_token_manager
-from fief.dependencies.current_account import get_current_account
+from fief.dependencies.current_workspace import get_current_workspace
 from fief.dependencies.tenant import get_current_tenant
 from fief.dependencies.token import get_user_from_grant_request, validate_grant_request
+from fief.dependencies.workspace_managers import get_refresh_token_manager
 from fief.managers import RefreshTokenManager
-from fief.models import Account, Client, RefreshToken, Tenant
+from fief.models import Client, RefreshToken, Tenant, Workspace
 from fief.schemas.auth import TokenResponse
 from fief.schemas.user import UserDB
 
@@ -26,12 +26,12 @@ async def token(
     grant_request: Tuple[UUID4, List[str], Client] = Depends(validate_grant_request),
     user: UserDB = Depends(get_user_from_grant_request),
     refresh_token_manager: RefreshTokenManager = Depends(get_refresh_token_manager),
-    account: Account = Depends(get_current_account),
+    workspace: Workspace = Depends(get_current_workspace),
     tenant: Tenant = Depends(get_current_tenant),
 ):
     _, scope, client = grant_request
 
-    tenant_host = tenant.get_host(account.domain)
+    tenant_host = tenant.get_host(workspace.domain)
     access_token = generate_access_token(
         tenant.get_sign_jwk(), tenant_host, client, user, scope, TOKEN_LIFETIME
     )
