@@ -5,7 +5,7 @@ from fastapi.security import HTTPAuthorizationCredentials, HTTPBearer
 from pydantic import UUID4
 from sqlalchemy import select
 
-from fief.dependencies.current_account import get_current_account
+from fief.dependencies.current_workspace import get_current_workspace
 from fief.dependencies.main_managers import get_admin_api_key_manager
 from fief.dependencies.pagination import (
     Ordering,
@@ -16,7 +16,7 @@ from fief.dependencies.pagination import (
     get_pagination,
 )
 from fief.managers import AdminAPIKeyManager
-from fief.models import Account, AdminAPIKey
+from fief.models import AdminAPIKey, Workspace
 
 bearer_scheme = HTTPBearer(auto_error=False)
 
@@ -35,20 +35,22 @@ async def get_paginated_api_keys(
     pagination: Pagination = Depends(get_pagination),
     ordering: Ordering = Depends(get_ordering),
     manager: AdminAPIKeyManager = Depends(get_admin_api_key_manager),
-    current_account: Account = Depends(get_current_account),
+    current_workspace: Workspace = Depends(get_current_workspace),
 ) -> PaginatedObjects[AdminAPIKey]:
-    statement = select(AdminAPIKey).where(AdminAPIKey.account_id == current_account.id)
+    statement = select(AdminAPIKey).where(
+        AdminAPIKey.workspace_id == current_workspace.id
+    )
     return await get_paginated_objects(statement, pagination, ordering, manager)
 
 
 async def get_api_key_by_id_or_404(
     id: UUID4,
     manager: AdminAPIKeyManager = Depends(get_admin_api_key_manager),
-    current_account: Account = Depends(get_current_account),
+    current_workspace: Workspace = Depends(get_current_workspace),
 ) -> AdminAPIKey:
     statement = select(AdminAPIKey).where(
         AdminAPIKey.id == id,
-        AdminAPIKey.account_id == current_account.id,
+        AdminAPIKey.workspace_id == current_workspace.id,
     )
     api_key = await manager.get_one_or_none(statement)
 
